@@ -30,11 +30,11 @@ use core::arch::x86::{_mm_prefetch, _MM_HINT_T0};
 #[allow(unused_assignments)]
 #[inline(always)]
 pub fn format_iso8061<S: TimestampStrStorage>(ts: PrimitiveDateTime, offset: UtcOffset) -> TimestampStr<S> {
-    // prefetch the table while datetime parts are being destructured
     let lookup = LOOKUP.as_ptr();
-    if cfg!(any(target_arch = "x86_64", target_arch = "x86")) {
-        unsafe { _mm_prefetch::<_MM_HINT_T0>(lookup as _) }
-    }
+
+    // prefetch the table while datetime parts are being destructured
+    #[cfg(any(target_arch = "x86_64", target_arch = "x86"))]
+    unsafe { _mm_prefetch::<_MM_HINT_T0>(lookup as _) }
 
     // decompose timestamp
     //let (year, month, day) = get_ymd(ts.date());
@@ -54,9 +54,11 @@ pub fn format_iso8061<S: TimestampStrStorage>(ts: PrimitiveDateTime, offset: Utc
 
             let buf = buf.as_mut_ptr().add(pos);
 
-            // process 2 digits per iteration, this loop will be unrolled
+            // process 2 digits per iteration, this loop will likely be unrolled
             while len >= 2 {
-                let d1 = value % 100;
+                // skip modulus if on last 2 digits, made non-branching when unrolled
+                let d1 = if len > 2 { value % 100 } else { value };
+
                 len -= 2;
                 buf.add(len).copy_from_nonoverlapping(lookup.add(d1 as usize) as *const u8, 2);
 
